# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import dbus, modules, time, tools, traceback

from gettext   import gettext as _
from tools.log import logger

MOD_NAME = _('Gnome Media Keys')

class GnomeMediaKeys(modules.Module):
    """ Support for Gnome multimedia keys """

    def __init__(self, wTree):
        modules.Module.__init__(self)
        modules.register(self, (modules.MSG_EVT_APP_STARTED, modules.MSG_EVT_APP_QUIT))
        self.dbusInterface = None

    def handleMsg(self, msg, params):
        """ Handle messages sent to this modules """
        if msg == modules.MSG_EVT_APP_STARTED:
            try:
                service = dbus.SessionBus().get_object('org.gnome.SettingsDaemon', '/org/gnome/SettingsDaemon')
                self.dbusInterface = dbus.Interface(service, 'org.gnome.SettingsDaemon')
                self.dbusInterface.GrabMediaPlayerKeys(tools.consts.appName, time.time())
                self.dbusInterface.connect_to_signal('MediaPlayerKeyPressed', self.onMediaKey)
            except:
                logger.error('[%s] Error while initializing\n\n%s' % (MOD_NAME, traceback.format_exc()))
                self.dbusInterface = None
        elif msg == modules.MSG_EVT_APP_QUIT and self.dbusInterface is not None:
            self.dbusInterface.ReleaseMediaPlayerKeys(tools.consts.appName)

    def onMediaKey(self, appName, action):
        """ A media key has been pressed """
        if appName == tools.consts.appName:
            if action == 'Stop':              modules.postMsg(modules.MSG_CMD_STOP)
            elif action == 'Next':            modules.postMsg(modules.MSG_CMD_NEXT)
            elif action == 'Previous':        modules.postMsg(modules.MSG_CMD_PREVIOUS)
            elif action in ['Play', 'Pause']: modules.postMsg(modules.MSG_CMD_TOGGLE_PAUSE)
